=================================================
Documentation for Handlebars integration in Plone
=================================================


Python integration
https://github.com/wbond/pybars3

Templating engine
https://handlebarsjs.com

Example:

http://unic.github.io/estatico/


Limitations:
The Python implementation does only understand double quotes `"` in templates. Make sure you communicate this to
your agency.

